#!/bin/bash

mypath=$(dirname "$0");
execfile=$(basename "$0");

soundcard="";
alsa_datadir="";
uninstall=0;

function printHelpAndExit {
  echo "Usage:";
  echo "$execfile [options] soundcard       install/uninstall ucm scripts"
  echo "  soundcard list -- ";
  for file in $mypath/ucm/*; do
    echo "  *" $(basename "$file");
  done
  echo ""
  echo "  Options:"
  echo "    -p <path>                 alsa data dir path"
  echo "    -u                        uninstall ucm configurations"
  echo "    -h                        print help"
  exit $1;
}

if [ $# -lt 1 ]; then
  printHelpAndExit 1;
fi

while getopts "hup:" optionName; do
case "$optionName" in
h) printHelpAndExit 0;;
p) alsa_datadir="$OPTARG";;
u) uninstall=1;;
[?]) printHelpAndExit 1;;
esac
done

soundcard="${!#}";
echo "use soundcard :" $soundcard

if [ -z "$soundcard" ]; then
  echo "soundcard must be specified -- ";
  printHelpAndExit 1;
fi

if ! [ -d "$mypath/ucm/$soundcard" ]; then
  echo "soundcard $soundcard not exists"
  exit 1;
fi

if [ -z "$alsa_datadir" ]; then
  prefix=`pkg-config --variable=prefix alsa`
  if [ -z "$prefix" ] ; then
    prefix=/usr
  fi
  ucmdir="$prefix/share/alsa/ucm";
else
  ucmdir="$alsa_datadir/ucm"
fi

echo "srcdir = $mypath/ucm/$soundcard"
echo "destdir = $ucmdir"

mkdir -p $ucmdir

if [ "$uninstall" -ne 0 ]; then
  rm -rf $ucmdir/$soundcard;
else
  cp -rf $mypath/ucm/$soundcard $ucmdir;
fi

echo "Done !!!"
